@@ -1,19 +1,19 @@
 import os
-from typing import Mapping, Iterator, NoReturn, Any
+from typing import Mapping, Iterator, NoReturn, Any, Optional, Dict
 
 import dotenv
 
 
-class _ExtendedEnviron(Mapping[str, str]):
-    def __init__(self) -> None:
-        self._dot_env: Mapping[str, str] = dotenv.dotenv_values(".env") or {}
+class ExtendedEnviron(Mapping[str, str]):
+    def __init__(self, read_dot_env_file: bool) -> None:
+        self._dot_env: Dict[str, Optional[str]] = dotenv.dotenv_values(".env") if read_dot_env_file else {}
 
     def __getitem__(self, key: str) -> str:
         if not isinstance(key, str):
             raise ValueError(f"str expected, not {type(key)}")
 
         try:
-            return os.environ.get(key, self._dot_env[key])
+            return self.get_dot_env_combined_with_environ()[key]
         except KeyError:
             raise KeyError(key) from None
 
@@ -26,8 +26,5 @@ class _ExtendedEnviron(Mapping[str, str]):
     def __iter__(self) -> Iterator[str]:
         return iter(self.get_dot_env_combined_with_environ())
 
-    def get_dot_env_combined_with_environ(self) -> Mapping[str, str]:
-        return {**self._dot_env, **os.environ}
-
-
-extended_environ = _ExtendedEnviron()
+    def get_dot_env_combined_with_environ(self) -> Mapping:
+        return {**self._dot_env, **os.environ} if self._dot_env else os.environ
